@@ -5,6 +5,7 @@ package mount
 
 import (
 	"context"
+	"syscall"
 	"time"
 
 	"bazil.org/fuse"
@@ -36,7 +37,6 @@ func (f *File) Attr(ctx context.Context, a *fuse.Attr) (err error) {
 	a.Atime = modTime
 	a.Mtime = modTime
 	a.Ctime = modTime
-	a.Crtime = modTime
 	a.Blocks = Blocks
 	return nil
 }
@@ -98,14 +98,14 @@ func (f *File) Fsync(ctx context.Context, req *fuse.FsyncRequest) (err error) {
 //
 // If there is no xattr by that name, returns fuse.ErrNoXattr.
 func (f *File) Getxattr(ctx context.Context, req *fuse.GetxattrRequest, resp *fuse.GetxattrResponse) error {
-	return fuse.ENOSYS // we never implement this
+	return syscall.ENOSYS // we never implement this
 }
 
 var _ fusefs.NodeGetxattrer = (*File)(nil)
 
 // Listxattr lists the extended attributes recorded for the node.
 func (f *File) Listxattr(ctx context.Context, req *fuse.ListxattrRequest, resp *fuse.ListxattrResponse) error {
-	return fuse.ENOSYS // we never implement this
+	return syscall.ENOSYS // we never implement this
 }
 
 var _ fusefs.NodeListxattrer = (*File)(nil)
@@ -113,7 +113,7 @@ var _ fusefs.NodeListxattrer = (*File)(nil)
 // Setxattr sets an extended attribute with the given name and
 // value for the node.
 func (f *File) Setxattr(ctx context.Context, req *fuse.SetxattrRequest) error {
-	return fuse.ENOSYS // we never implement this
+	return syscall.ENOSYS // we never implement this
 }
 
 var _ fusefs.NodeSetxattrer = (*File)(nil)
@@ -122,7 +122,7 @@ var _ fusefs.NodeSetxattrer = (*File)(nil)
 //
 // If there is no xattr by that name, returns fuse.ErrNoXattr.
 func (f *File) Removexattr(ctx context.Context, req *fuse.RemovexattrRequest) error {
-	return fuse.ENOSYS // we never implement this
+	return syscall.ENOSYS // we never implement this
 }
 
 var _ fusefs.NodeRemovexattrer = (*File)(nil)
