@@ -1,8 +1,10 @@
 package http
 
 import (
+	"bytes"
 	"embed"
 	"html/template"
+	"log"
 	"os"
 	"time"
 
@@ -11,11 +13,12 @@ import (
 	"github.com/rclone/rclone/fs/config/flags"
 )
 
-// TemplateHelp describes how to use a custom template
-var TemplateHelp = `
+// TemplateHelp returns a string that describes how to use a custom template
+func TemplateHelp(prefix string) string {
+	help := `
 #### Template
 
-` + "`--template`" + ` allows a user to specify a custom markup template for HTTP
+` + "`--{{ .Prefix }}template`" + ` allows a user to specify a custom markup template for HTTP
 and WebDAV serve functions.  The server exports the following markup
 to be used within the template to server pages:
 
@@ -39,6 +42,24 @@ to be used within the template to server pages:
 |-- .ModTime  | The UTC timestamp of an entry. |
 `
 
+	tmpl, err := template.New("template help").Parse(help)
+	if err != nil {
+		log.Fatal("Fatal error parsing template", err)
+	}
+
+	data := struct {
+		Prefix string
+	}{
+		Prefix: prefix,
+	}
+	buf := &bytes.Buffer{}
+	err = tmpl.Execute(buf, data)
+	if err != nil {
+		log.Fatal("Fatal error executing template", err)
+	}
+	return buf.String()
+}
+
 // TemplateConfig for the templating functionality
 type TemplateConfig struct {
 	Path string
